@@ -56,6 +56,7 @@ TFB_GRAPHICS_BACKEND *graphics_backend = NULL;
 int RenderedFrames = 0;
 
 volatile int QuitPosted = 0;
+volatile int GameActive = 1; // Track the SDL_ACTIVEEVENT state SDL_APPACTIVE
 
 void
 TFB_PreInit (void)
@@ -185,6 +186,7 @@ void
 TFB_UninitGraphics (void)
 {
 	Uninit_DrawCommandQueue ();
+	// TODO: Uninit whatever the drivers have set up for us
 	SDL_Quit ();
 }
 
@@ -197,11 +199,17 @@ TFB_ProcessEvents ()
 	{
 		/* Run through the InputEvent filter. */
 		ProcessInputEvent (&Event);
-		/* Handle Graphics events. */
+		/* Handle graphics and exposure events. */
 		switch (Event.type) {
-			case SDL_ACTIVEEVENT:    /* Lose/gain visibility */
-				// TODO
-				break;
+			case SDL_ACTIVEEVENT:    /* Lose/gain visibility or focus */
+				/* Up to three different state changes can occur in one event. */
+				/* Here, disregard least significant change (mouse focus). */
+				// This controls the automatic sleep/pause when minimized.
+				// On small displays (e.g. mobile devices), APPINPUTFOCUS would 
+				//  be an appropriate substitution for APPACTIVE:
+				if (Event.active.state & SDL_APPINPUTFOCUS)
+					GameActive = Event.active.gain;
+ 				break;
 			case SDL_QUIT:
 				QuitPosted = 1;
 				break;
@@ -859,16 +867,18 @@ TFB_FlushGraphics (void) // Only call from main thread!!
 		case TFB_DRAWCOMMANDTYPE_REINITVIDEO:
 			{
 				int oldDriver = GraphicsDriver;
+				int oldFlags = GfxFlags;
+				int oldWidth = ScreenWidthActual;
+				int oldHeight = ScreenHeightActual;
 				if (TFB_ReInitGraphics (DC.data.reinitvideo.driver,
 						DC.data.reinitvideo.flags,
 						DC.data.reinitvideo.width, DC.data.reinitvideo.height))
 				{
 					log_add (log_Error, "Could not provide requested mode: "
 							"reverting to last known driver.");
-					if (TFB_ReInitGraphics (oldDriver,
-							DC.data.reinitvideo.flags,
-							DC.data.reinitvideo.width,
-							DC.data.reinitvideo.height))
+					// We don't know what exactly failed, so roll it all back
+					if (TFB_ReInitGraphics (oldDriver, oldFlags,
+							oldWidth, oldHeight))
 					{
 						log_add (log_Fatal,
 								"Couldn't reinit at that point either. "
