@@ -433,6 +433,10 @@ main (int argc, char *argv[])
 			SignalStopMainThread ();
 			++i;
 		}
+		else if (!GameActive)
+		{	// Throttle down the main loop when game is inactive
+			SleepThread (ONE_SECOND / 4);
+		}
 
 		TFB_ProcessEvents ();
 		ProcessUtilityKeys ();
