@@ -569,19 +569,16 @@ SpewPhrases (COUNT wait_track)
 
 	which_track = PlayingTrack ();
 	if (which_track == 0 && !rewind)
-	{
-		// initial start of player
-		if (wait_track == 1 || wait_track == (COUNT)~0)
+	{	// initial start of player
+		UnlockMutex (GraphicsLock);
+		PlayTrack ();
+		// wait for the trackplayer to start playing
+		do
 		{
-			UnlockMutex (GraphicsLock);
-			PlayTrack ();
-			do
-			{
-				TaskSwitch ();
-				which_track = PlayingTrack ();
-			} while (!which_track);
-			LockMutex (GraphicsLock);
-		}
+			TaskSwitch ();
+			which_track = PlayingTrack ();
+		} while (!which_track);
+		LockMutex (GraphicsLock);
 	}
 	else if (which_track <= wait_track)
 	{	// XXX: I don't know why this is here, but it is not harmful.
@@ -1438,8 +1435,8 @@ InitCommunication (CONVERSATION which_comm)
 				|| LOBYTE (GLOBAL (CurrentActivity)) == IN_LAST_BATTLE))
 				|| (which_comm != CHMMR_CONVERSATION
 				&& which_comm != SYREEN_CONVERSATION
-				))//&& (ActivateStarShip (status, CHECK_ALLIANCE) & BAD_GUY)))
-			BuildBattle (1);
+				))//&& ActivateStarShip (status, CHECK_ALLIANCE) == BAD_GUY))
+			BuildBattle (NPC_PLAYER_NUM);
 	}
 
 	LocDataPtr = init_race (
@@ -1498,7 +1495,7 @@ InitCommunication (CONVERSATION which_comm)
 		if (status)
 		{
 			// Start combat
-			BuildBattle (0);
+			BuildBattle (RPG_PLAYER_NUM);
 			EncounterBattle ();
 		}
 		else
@@ -1578,14 +1575,14 @@ RaceCommunication (void)
 			COUNT NumShips;
 			ENCOUNTER *EncounterPtr;
 
+			// The encounter globe that the flagship collided with is moved
+			// to the head of the queue in hyper.c:cleanup_hyperspace()
 			hEncounter = GetHeadEncounter ();
 			LockEncounter (hEncounter, &EncounterPtr);
 
 			NumShips = LONIBBLE (EncounterPtr->SD.Index);
 			for (i = 0; i < NumShips; ++i)
 			{
-				// XXX: Bug 996 lives here: crew is set to default (0)
-				//   None of ship info is actually used!
 				CloneShipFragment (EncounterPtr->SD.Type,
 						&GLOBAL (npc_built_ship_q),
 						EncounterPtr->ShipList[i].crew_level);
