@@ -170,7 +170,7 @@ LoadShipQueue (DECODE_REF fh, QUEUE *pQueue)
 		FragPtr = LockShipFrag (pQueue, hStarShip);
 
 		// Read SHIP_FRAGMENT elements
-		cread_16 (fh, &FragPtr->which_side);
+		cread_16 (fh, NULL); /* unused: was which_side */
 		cread_8  (fh, &FragPtr->captains_name_index);
 		cread_8  (fh, NULL); /* padding */
 		cread_16 (fh, NULL); /* unused: was ship_flags */
@@ -210,7 +210,7 @@ LoadRaceQueue (DECODE_REF fh, QUEUE *pQueue)
 		FleetPtr = LockFleetInfo (pQueue, hStarShip);
 
 		// Read FLEET_INFO elements
-		cread_16 (fh, &FleetPtr->ship_flags);
+		cread_16 (fh, &FleetPtr->allied_state);
 		cread_8  (fh, &FleetPtr->days_left);
 		cread_8  (fh, &FleetPtr->growth_fract);
 		cread_8  (fh, &tmpb);
@@ -371,7 +371,7 @@ LoadClockState (CLOCK_STATE *ClockPtr, DECODE_REF fh)
 	cread_16  (fh, &ClockPtr->day_in_ticks);
 	cread_ptr (fh); /* not loading ptr; Semaphore clock_sem */
 	cread_ptr (fh); /* not loading ptr; Task clock_task */
-	cread_32  (fh, &ClockPtr->TimeCounter); /* theoretically useless */
+	cread_32  (fh, NULL); /* not loading; DWORD TimeCounter */
 
 	DummyLoadQueue (&ClockPtr->event_q, fh);
 }
@@ -566,14 +566,6 @@ LoadGame (COUNT which_game, SUMMARY_DESC *SummPtr)
 	NextActivity = GLOBAL (CurrentActivity);
 	GLOBAL (CurrentActivity) = Activity;
 
-	// It shouldn't be possible to ever save with TimeCounter != 0
-	// But if it does happen, it needs to be reset to 0, since on load
-	// the clock semaphore is gauranteed to be 0
-	if (GLOBAL (GameClock.TimeCounter) != 0)
-		log_add (log_Warning, "Warning: Game clock wasn't stopped during "
-				"save, Savegame may be corrupt!\n");
-	GLOBAL (GameClock.TimeCounter) = 0;
-
 	LoadRaceQueue (fh, &GLOBAL (avail_race_q));
 	// START_INTERPLANETARY is only set when saving from Homeworld
 	//   encounter screen. When the game is loaded, GENERATE_ORBITAL will
