@@ -188,7 +188,6 @@ FRAME MeleeFrame;
 		// Loaded from melee/melebkgd.ani
 static FRAME BuildPickFrame;
 		// Constructed.
-DWORD LastInputTime;
 MELEE_STATE *pMeleeState;
 
 BOOLEAN DoMelee (MELEE_STATE *pMS);
@@ -895,7 +894,7 @@ DrawMeleeShipStrings (MELEE_STATE *pMS, BYTE NewStarShip)
 		RECT r;
 		TEXT t;
 
-		ClearShipStatus (BAD_GUY_YOFFS);
+		ClearShipStatus (0);
 		SetContextFont (StarConFont);
 		r.corner.x = 3;
 		r.corner.y = 4;
@@ -932,7 +931,7 @@ DrawMeleeShipStrings (MELEE_STATE *pMS, BYTE NewStarShip)
 		hMasterShip = GetStarShipFromIndex (&master_q, NewStarShip);
 		MasterPtr = LockMasterShip (&master_q, hMasterShip);
 
-		InitShipStatus (&MasterPtr->ShipInfo, ~0, NULL);
+		InitShipStatus (&MasterPtr->ShipInfo, NULL, NULL);
 
 		UnlockMasterShip (&master_q, hMasterShip);
 	}
@@ -1086,20 +1085,28 @@ DoEdit (MELEE_STATE *pMS)
 		pMS->MeleeOption = START_MELEE;
 		pMS->InputFunc = DoMelee;
 		UnlockMutex (GraphicsLock);
-		LastInputTime = GetTimeCounter ();
+		pMS->LastInputTime = GetTimeCounter ();
 	}
 	else if (pMS->row < NUM_MELEE_ROWS
-			&& (PulsedInputState.menu[KEY_MENU_SELECT] ||
-			PulsedInputState.menu[KEY_MENU_SPECIAL]))
+			&& PulsedInputState.menu[KEY_MENU_SELECT])
 	{
 		// Show a popup to add a new ship to the current team.
-		if (PulsedInputState.menu[KEY_MENU_SELECT])
-			pMS->Initialized = 0;
-		else
-			pMS->Initialized = -1;
+		pMS->Initialized = 0;
 		FlushInput ();
 		DoPickShip (pMS);
 	}
+	else if (pMS->row < NUM_MELEE_ROWS
+			&& PulsedInputState.menu[KEY_MENU_SPECIAL])
+	{
+		// TODO: this is a stub; Should we display a ship spin?
+		LockMutex (GraphicsLock);
+		Deselect (EDIT_MELEE);
+		if (pMS->CurIndex != (BYTE)~0)
+		{
+			// Do something with pMS->CurIndex here
+		}
+		UnlockMutex (GraphicsLock);
+	}
 	else if (pMS->row < NUM_MELEE_ROWS &&
 			PulsedInputState.menu[KEY_MENU_DELETE])
 	{
@@ -1232,35 +1239,17 @@ DoPickShip (MELEE_STATE *pMS)
 
 	SetMenuSounds (MENU_SOUND_ARROWS, MENU_SOUND_SELECT);
 
-	if (pMS->Initialized <= 0)
+	if (!pMS->Initialized)
 	{
-		if (pMS->CurIndex == (BYTE)~0 && pMS->Initialized == 0)
+		if (pMS->CurIndex == (BYTE)~0)
 			pMS->CurIndex = 0;
-		else if (pMS->CurIndex != (BYTE)~0)
-			DeleteCurrentShip (pMS);
 
-		if (pMS->Initialized == 0)
-		{
-			LockMutex (GraphicsLock);
-			Deselect (EDIT_MELEE);
-			pMS->InputFunc = DoPickShip;
-			DrawPickFrame (pMS);
-			pMS->Initialized = TRUE;
-			UnlockMutex (GraphicsLock);
-		}
-		else
-		{
-			FleetShipIndex fleetShipIndex = GetShipIndex (pMS->row, pMS->col);
-			LockMutex (GraphicsLock);
-			Deselect (EDIT_MELEE);
-			pMS->Initialized = TRUE;
-			AdvanceCursor (pMS);
-			pMS->CurIndex = pMS->SideState[pMS->side].TeamImage.ShipList[
-					fleetShipIndex];
-			UnlockMutex (GraphicsLock);
-
-			DrawMeleeShipStrings (pMS, (BYTE)(pMS->CurIndex));
-		}
+		LockMutex (GraphicsLock);
+		Deselect (EDIT_MELEE);
+		pMS->InputFunc = DoPickShip;
+		DrawPickFrame (pMS);
+		pMS->Initialized = TRUE;
+		UnlockMutex (GraphicsLock);
 	}
 	else if (PulsedInputState.menu[KEY_MENU_SELECT] ||
 			PulsedInputState.menu[KEY_MENU_CANCEL])
@@ -1688,7 +1677,7 @@ BuildAndDrawShipList (MELEE_STATE *pMS)
 				BuiltShipPtr = LockStarShip (&race_q[side], hBuiltShip);
 				BuiltShipPtr->index = index;
 				BuiltShipPtr->ship_cost = ship_cost;
-				BuiltShipPtr->which_side = 1 << side;
+				BuiltShipPtr->playerNr = side;
 				BuiltShipPtr->captains_name_index = captains_name_index;
 				// The next ones are not used in Melee
 				BuiltShipPtr->crew_level = 0;
@@ -1741,7 +1730,7 @@ StartMelee (MELEE_STATE *pMS)
 
 		load_gravity_well ((BYTE)((COUNT)TFB_Random () %
 					NUMBER_OF_PLANET_TYPES));
-		Battle ();
+		Battle (NULL);
 		free_gravity_well ();
 		ClearPlayerInputAll ();
 
@@ -1936,6 +1925,7 @@ DoConnectingDialog (MELEE_STATE *pMS)
 		}
 		RedrawMeleeFrame ();
 		pMS->InputFunc = DoMelee;
+		pMS->LastInputTime = GetTimeCounter ();
 		if (!pMS->flash_task)
 		{
 			pMS->flash_task = AssignTask (flash_selection_func, 2048,
@@ -1962,6 +1952,7 @@ DoConnectingDialog (MELEE_STATE *pMS)
 
 			UpdateMeleeStatusMessage (which_side);
 			pMS->InputFunc = DoMelee;
+			pMS->LastInputTime = GetTimeCounter ();
 			Deselect (pMS->MeleeOption);
 			pMS->MeleeOption = START_MELEE;
 			if (!pMS->flash_task)
@@ -2073,7 +2064,6 @@ MeleeOptionSelect (MELEE_STATE *pMS)
 			pMS->Initialized = FALSE;
 			pMS->side = pMS->MeleeOption == LOAD_TOP ? 0 : 1;
 			DoLoadTeam (pMS);
-			LastInputTime = GetTimeCounter ();
 			break;
 		case SAVE_TOP:
 		case SAVE_BOT:
@@ -2102,6 +2092,7 @@ MeleeOptionSelect (MELEE_STATE *pMS)
 			which_side = pMS->MeleeOption == NET_TOP ? 1 : 0;
 			confirmed = MeleeConnectDialog (which_side);
 			RedrawMeleeFrame ();
+			pMS->LastInputTime = GetTimeCounter ();
 			if (confirmed)
 			{
 				pMS->Initialized = FALSE;
@@ -2163,7 +2154,7 @@ DoMelee (MELEE_STATE *pMS)
 				
 			XFormColorMap ((COLORMAPPTR)clut_buf, ONE_SECOND / 2);
 		}
-		LastInputTime = GetTimeCounter ();
+		pMS->LastInputTime = GetTimeCounter ();
 		return TRUE;
 	}
 
@@ -2176,7 +2167,7 @@ DoMelee (MELEE_STATE *pMS)
 	{
 		// Start editing the teams.
 		LockMutex (GraphicsLock);
-		LastInputTime = GetTimeCounter ();
+		pMS->LastInputTime = GetTimeCounter ();
 		Deselect (pMS->MeleeOption);
 		UnlockMutex (GraphicsLock);
 		pMS->MeleeOption = EDIT_MELEE;
@@ -2202,17 +2193,17 @@ DoMelee (MELEE_STATE *pMS)
 		NewMeleeOption = pMS->MeleeOption;
 		if (PulsedInputState.menu[KEY_MENU_UP])
 		{
-			LastInputTime = GetTimeCounter ();
+			pMS->LastInputTime = GetTimeCounter ();
 			NewMeleeOption = MeleeOptionUp (pMS->MeleeOption);
 		}
 		else if (PulsedInputState.menu[KEY_MENU_DOWN])
 		{
-			LastInputTime = GetTimeCounter ();
+			pMS->LastInputTime = GetTimeCounter ();
 			NewMeleeOption = MeleeOptionDown (pMS->MeleeOption);
 		}
 
 		if ((PlayerControl[0] & PlayerControl[1] & PSYTRON_CONTROL)
-				&& GetTimeCounter () - LastInputTime > ONE_SECOND * 10)
+				&& GetTimeCounter () - pMS->LastInputTime > ONE_SECOND * 10)
 		{
 			force_select = TRUE;
 			NewMeleeOption = START_MELEE;
