@@ -22,7 +22,7 @@
 #include "libs/gfxlib.h"
 #include "libs/sndlib.h"
 #include "libs/tasklib.h"
-
+#include "flash.h"
 
 typedef struct menu_state
 {
@@ -41,6 +41,7 @@ typedef struct menu_state
 	Task flash_task;
 	RECT flash_rect0, flash_rect1;
 	FRAME flash_frame0, flash_frame1;
+	FlashContext *flashContext;
 
 	MUSIC_REF hMusic;
 
