@@ -47,8 +47,6 @@ static void reportShipSelected (GETMELEE_STATE *gms, COUNT index);
 #endif
 
 // Returns the <index>th ship in the queue, or 0 if it is not available.
-// For all the ships in the queue, the ShipFacing field contains the
-// index in the queue.
 static HSTARSHIP
 MeleeShipByQueueIndex (const QUEUE *queue, COUNT index)
 {
@@ -582,7 +580,8 @@ GetMeleeStarShips (COUNT playerMask, HSTARSHIP *ships)
 #endif
 
 		gmstate.player[playerI].flashContext =
-				Flash_createHighlight (ScreenContext, (FRAME) 0, NULL,
+				Flash_createHighlight (ScreenContext, (FRAME) 0, NULL);
+		Flash_setMergeFactors (gmstate.player[playerI].flashContext,
 				2, 3, 2);
 		Flash_setFrameTime (gmstate.player[playerI].flashContext,
 				ONE_SECOND / 16);
