@@ -146,7 +146,7 @@ SaveShipQueue (DECODE_REF fh, QUEUE *pQueue)
 		cwrite_16 (fh, Index);
 
 		// Write SHIP_FRAGMENT elements
-		cwrite_16 (fh, FragPtr->which_side);
+		cwrite_16 (fh, 0); /* unused; was which_side */
 		cwrite_8  (fh, FragPtr->captains_name_index);
 		cwrite_8  (fh, 0); /* padding */
 		cwrite_16 (fh, 0); /* unused: was ship_flags */
@@ -190,7 +190,7 @@ SaveRaceQueue (DECODE_REF fh, QUEUE *pQueue)
 		cwrite_16 (fh, Index);
 
 		// Write FLEET_INFO elements
-		cwrite_16 (fh, FleetPtr->ship_flags);
+		cwrite_16 (fh, FleetPtr->allied_state);
 		cwrite_8  (fh, FleetPtr->days_left);
 		cwrite_8  (fh, FleetPtr->growth_fract);
 		cwrite_8  (fh, FleetPtr->crew_level);
@@ -341,7 +341,7 @@ SaveClockState (const CLOCK_STATE *ClockPtr, DECODE_REF fh)
 	cwrite_16  (fh, ClockPtr->day_in_ticks);
 	cwrite_ptr (fh); /* useless ptr; Semaphore clock_sem */
 	cwrite_ptr (fh); /* useless ptr; Task clock_task */
-	cwrite_32  (fh, ClockPtr->TimeCounter); /* theoretically useless */
+	cwrite_32  (fh, 0); /* useless value; DWORD TimeCounter */
 
 	DummySaveQueue (&ClockPtr->event_q, fh);
 }
