@@ -185,51 +185,46 @@ DrawSISMessageEx (const UNICODE *pStr, SIZE CurPos, SIZE ExPos, COUNT flags)
 	SetContextBackGroundColor (
 			BUILD_COLOR (MAKE_RGB15 (0x00, 0x00, 0x14), 0x01));
 
-	if (pStr == (UNICODE *)~0L)
+	if (pStr == 0)
 	{
-		if (GLOBAL_SIS (FuelOnBoard) == 0)
-			pStr = GAME_STRING (NAVIGATION_STRING_BASE + 2);
-		else
-			pStr = GAME_STRING (NAVIGATION_STRING_BASE + 3);
-	}
-	else
-	{
-		if (pStr == 0)
+		switch (LOBYTE (GLOBAL (CurrentActivity)))
 		{
-			switch (LOBYTE (GLOBAL (CurrentActivity)))
-			{
-				default:
-				case IN_ENCOUNTER:
-					buf[0] = '\0';
-					break;
-				case IN_LAST_BATTLE:
-				case IN_INTERPLANETARY:
-					GetClusterName (CurStarDescPtr, buf);
-					break;
-				case IN_HYPERSPACE:
-					utf8StringCopy (buf, sizeof (buf),
-							GAME_STRING (NAVIGATION_STRING_BASE
-								+ (GET_GAME_STATE (ARILOU_SPACE_SIDE) <= 1
-									? 0 : 1)));
-					break;
-			}
-
-			pStr = buf;
+			default:
+			case IN_ENCOUNTER:
+				pStr = "";
+				break;
+			case IN_LAST_BATTLE:
+			case IN_INTERPLANETARY:
+				GetClusterName (CurStarDescPtr, buf);
+				pStr = buf;
+				break;
+			case IN_HYPERSPACE:
+				if (GET_GAME_STATE (ARILOU_SPACE_SIDE) <= 1)
+				{
+					pStr = GAME_STRING (NAVIGATION_STRING_BASE);
+							// "HyperSpace"
+				}
+				else
+				{
+					pStr = GAME_STRING (NAVIGATION_STRING_BASE + 1);
+							// "QuasiSpace"
+				}
+				break;
 		}
 
+	}
+
+	if (!(flags & DSME_MYCOLOR))
 		SetContextForeGroundColor (
 				BUILD_COLOR (MAKE_RGB15 (0x1B, 0x00, 0x1B), 0x33));
-	}
 
 	t.baseline.y = SIS_MESSAGE_HEIGHT - 2;
 	t.pStr = pStr;
-	t.CharCount = utf8StringCount(pStr);
+	t.CharCount = (COUNT)~0;
 	SetContextFont (TinyFont);
 
 	if (flags & DSME_CLEARFR)
-	{
-		SetFlashRect (NULL, (FRAME)0);
-	}
+		SetFlashRect (NULL);
 
 	if (CurPos < 0 && ExPos < 0)
 	{	// normal state
@@ -321,8 +316,9 @@ DrawSISMessageEx (const UNICODE *pStr, SIZE CurPos, SIZE ExPos, COUNT flags)
 
 	if (flags & DSME_SETFR)
 	{
-		r.corner.x = r.corner.y = 0;
-		SetFlashRect (&r, (FRAME)0);
+		r.corner.x = 0;
+		r.corner.y = 0;
+		SetFlashRect (&r);
 	}
 
 	UnbatchGraphics ();
@@ -1288,9 +1284,77 @@ CountSISPieces (BYTE piece_type)
 	return (num_pieces);
 }
 
+void
+DrawAutoPilotMessage (BOOLEAN Reset)
+{
+	static BOOLEAN LastPilot = FALSE;
+	static TimeCount NextTime = 0;
+	static DWORD cycle_index = 0;
+	BOOLEAN OnAutoPilot;
+	
+	static const COLOR cycle_tab[] =
+	{
+		BUILD_COLOR (MAKE_RGB15 (0x0A, 0x14, 0x18), 0x5B),
+		BUILD_COLOR (MAKE_RGB15 (0x06, 0x10, 0x16), 0x5C),
+		BUILD_COLOR (MAKE_RGB15 (0x03, 0x0E, 0x14), 0x5D),
+		BUILD_COLOR (MAKE_RGB15 (0x02, 0x0C, 0x11), 0x5E),
+		BUILD_COLOR (MAKE_RGB15 (0x01, 0x0B, 0x0F), 0x5F),
+		BUILD_COLOR (MAKE_RGB15 (0x01, 0x09, 0x0D), 0x60),
+		BUILD_COLOR (MAKE_RGB15 (0x00, 0x07, 0x0B), 0x61),
+	};
+#define NUM_CYCLES (sizeof (cycle_tab) / sizeof (cycle_tab[0]))
+#define BLINK_RATE (ONE_SECOND * 3 / 40) // 9 @ 120 ticks/second
+
+
+	if (Reset)
+	{	// Just a reset, not drawing
+		LastPilot = FALSE;
+		return;
+	}
+
+	OnAutoPilot = (GLOBAL (autopilot.x) != ~0 && GLOBAL (autopilot.y) != ~0)
+			|| GLOBAL_SIS (FuelOnBoard) == 0;
+
+	if (OnAutoPilot || LastPilot)
+	{
+		if (!OnAutoPilot)
+		{	// AutiPilot aborted -- clear the AUTO-PILOT message
+			DrawSISMessage (NULL);
+			cycle_index = 0;
+		}
+		else if (GetTimeCounter () >= NextTime)
+		{
+			if (!(GLOBAL (CurrentActivity) & CHECK_ABORT)
+					&& GLOBAL_SIS (CrewEnlisted) != (COUNT)~0)
+			{
+				CONTEXT OldContext;
+
+				OldContext = SetContext (OffScreenContext);
+				SetContextForeGroundColor (cycle_tab[cycle_index]);
+				if (GLOBAL_SIS (FuelOnBoard) == 0)
+				{
+					DrawSISMessageEx (GAME_STRING (NAVIGATION_STRING_BASE + 2),
+							-1, -1, DSME_MYCOLOR);   // "OUT OF FUEL"
+				}
+				else
+				{
+					DrawSISMessageEx (GAME_STRING (NAVIGATION_STRING_BASE + 3),
+							-1, -1, DSME_MYCOLOR);   // "AUTO-PILOT"
+				}
+				SetContext (OldContext);
+			}
+
+			cycle_index = (cycle_index + 1) % NUM_CYCLES;
+			NextTime = GetTimeCounter () + BLINK_RATE;
+		}
+
+		LastPilot = OnAutoPilot;
+	}
+}
+
+
 Task flash_task = 0;
 RECT flash_rect;
-static FRAME flash_frame;
 static FRAME flash_screen_frame = 0;
 static int flash_changed;
 Mutex flash_mutex = 0;
@@ -1307,8 +1371,7 @@ flash_rect_func (void *data)
 #define CACHE_SIZE 10
 	DWORD TimeIn, WaitTime;
 	SIZE strength, fstrength, incr;
-	RECT cached_rect, framesize_rect;
-	FRAME cached_frame = 0;
+	RECT cached_rect;
 	FRAME cached_screen_frame = 0;
 	Task task = (Task)data;
 	int cached[CACHE_SIZE];
@@ -1334,22 +1397,20 @@ flash_rect_func (void *data)
 		{
 			RECT screen_rect;
 			cached_rect = flash_rect;
-			cached_frame = flash_frame;
 			if (cached_screen_frame)
 				DestroyDrawable (ReleaseDrawable (cached_screen_frame));
 			flash_changed = 0;
 			//  Wait for the  flash_screen_frame to get initialized
 			FlushGraphics ();
 			GetFrameRect (flash_screen_frame, &screen_rect);
-			cached_screen_frame = CaptureDrawable (CreateDrawable (WANT_PIXMAP, 
-					screen_rect.extent.width, screen_rect.extent.height, 1));
+			cached_screen_frame = CaptureDrawable (CreateDrawable (
+					WANT_PIXMAP, screen_rect.extent.width,
+					screen_rect.extent.height, 1));
 			screen_rect.corner.x = 0;
 			screen_rect.corner.y = 0;
-			arith_frame_blit (flash_screen_frame, &screen_rect, 
+			arith_frame_blit (flash_screen_frame, &screen_rect,
 					cached_screen_frame, NULL, 0, 0);
 			UnlockMutex (flash_mutex);
-			if (cached_frame)
-				GetFrameRect (cached_frame, &framesize_rect);
 			for (i = 0; i < CACHE_SIZE; i++)
 			{
 				cached[i] = 0;
@@ -1364,85 +1425,31 @@ flash_rect_func (void *data)
 		if (cached_rect.extent.width)
 		{
 			STAMP *pStamp;
-			if (cached_frame)
-			{
-#define MIN_F_STRENGTH -3
-#define MAX_F_STRENGTH 3
-				int num = 0, denom = 0;
-
-				if ((fstrength += incr) > MAX_F_STRENGTH)
-				{
-					fstrength = MAX_F_STRENGTH - 1;
-					incr = -1;
-				}
-				else if (fstrength < MIN_F_STRENGTH)
-				{
-					fstrength = MIN_F_STRENGTH + 1;
-					incr = 1;
-				}
-				if (cached[fstrength - MIN_F_STRENGTH])
-					pStamp = &cached_stamp[fstrength - MIN_F_STRENGTH];
-				else
-				{
-					RECT tmp_rect = framesize_rect;
-					pStamp = &cached_stamp[fstrength - MIN_F_STRENGTH];
-					cached[fstrength - MIN_F_STRENGTH] = 1;
-					pStamp->frame = CaptureDrawable (CreateDrawable (WANT_PIXMAP, 
-							framesize_rect.extent.width, framesize_rect.extent.height, 1));
-					pStamp->origin.x = framesize_rect.corner.x;
-					pStamp->origin.y = framesize_rect.corner.y;
-					tmp_rect.corner.x = 0;
-					tmp_rect.corner.y = 0;
-
-					if (fstrength != NORMAL_F_STRENGTH)
-					{
-						arith_frame_blit (cached_frame, &tmp_rect, pStamp->frame, NULL,
-								fstrength > 0 ? fstrength : -fstrength, 16);
-
-						if (fstrength < 0)
-						{
-							// Subtractive blit.
-							num = -8;
-							denom = 8;
-						}
-						else
-						{
-							// Additive blit.
-							num = 8;
-							denom = -8;
-						}
-					}
-
-					arith_frame_blit (cached_screen_frame, &framesize_rect, pStamp->frame, 
-							&tmp_rect, num, denom);
-				}
-			}
-			else
-			{
 #define MIN_STRENGTH 4
 #define MAX_STRENGTH 6
-				if ((strength += 2) > MAX_STRENGTH)
-					strength = MIN_STRENGTH;
-				if (cached[strength - MIN_STRENGTH])
-					pStamp = &cached_stamp[strength - MIN_STRENGTH];
-				else
-				{
-					RECT tmp_rect = cached_rect;
-					pStamp = &cached_stamp[strength - MIN_STRENGTH];
-					cached[strength - MIN_STRENGTH] = 1;
-					pStamp->frame = CaptureDrawable (CreateDrawable (WANT_PIXMAP, 
-							cached_rect.extent.width, cached_rect.extent.height, 1));
-					pStamp->origin.x = 0;
-					pStamp->origin.y = 0;
-					tmp_rect.corner.x = 0;
-					tmp_rect.corner.y = 0;
+			strength += 2;
+			if (strength > MAX_STRENGTH)
+				strength = MIN_STRENGTH;
+			if (cached[strength - MIN_STRENGTH])
+				pStamp = &cached_stamp[strength - MIN_STRENGTH];
+			else
+			{
+				RECT tmp_rect = cached_rect;
+				pStamp = &cached_stamp[strength - MIN_STRENGTH];
+				cached[strength - MIN_STRENGTH] = 1;
+				pStamp->frame = CaptureDrawable (CreateDrawable (WANT_PIXMAP,
+						cached_rect.extent.width, cached_rect.extent.height,
+						1));
+				pStamp->origin.x = 0;
+				pStamp->origin.y = 0;
+				tmp_rect.corner.x = 0;
+				tmp_rect.corner.y = 0;
 
-					arith_frame_blit (cached_screen_frame, &tmp_rect, pStamp->frame, 
-							&tmp_rect, 4, 4);
-					if (strength != 4)
-						arith_frame_blit (cached_screen_frame, &tmp_rect, pStamp->frame, 
-								&tmp_rect, strength, 4);
-				}
+				arith_frame_blit (cached_screen_frame, &tmp_rect,
+						pStamp->frame, &tmp_rect, 4, 4);
+				if (strength != 4)
+					arith_frame_blit (cached_screen_frame, &tmp_rect,
+							pStamp->frame, &tmp_rect, strength, 4);
 			}
 			LockMutex (GraphicsLock);
 			OldContext = SetContext (ScreenContext);
@@ -1477,18 +1484,17 @@ flash_rect_func (void *data)
 }
 
 void
-SetFlashRect (RECT *pRect, FRAME f)
+SetFlashRect (RECT *pRect)
 {
 	RECT clip_r, temp_r, flash_rect1, old_r;
 	CONTEXT OldContext;
-	FRAME old_f;
 	int create_flash = 0;
 
 	if (! flash_mutex)
-		flash_mutex = CreateMutex ("FlashRect Lock", SYNC_CLASS_TOPLEVEL | SYNC_CLASS_VIDEO);
+		flash_mutex = CreateMutex ("FlashRect Lock",
+				SYNC_CLASS_TOPLEVEL | SYNC_CLASS_VIDEO);
 
 	old_r = flash_rect;
-	old_f = flash_frame;
 	flash_rect1 = flash_rect;
 		
 	if (pRect != SFR_MENU_3DO && pRect != SFR_MENU_ANY)
@@ -1536,15 +1542,13 @@ SetFlashRect (RECT *pRect, FRAME f)
 	}
 	
 	LockMutex (flash_mutex);
-	flash_frame = f;
 	flash_rect = flash_rect1;
 
 	if (old_r.extent.width
 			&& (old_r.extent.width != flash_rect.extent.width
 			|| old_r.extent.height != flash_rect.extent.height
 			|| old_r.corner.x != flash_rect.corner.x
-			|| old_r.corner.y != flash_rect.corner.y
-			|| old_f != flash_frame))
+			|| old_r.corner.y != flash_rect.corner.y))
 	{
 		if (flash_screen_frame)
 		{
@@ -1629,8 +1633,7 @@ SaveFlagshipState (void)
 			{
 				GLOBAL (ip_planet) = pSolarSysState->pBaseDesc->pPrevDesc
 						- pSolarSysState->PlanetDesc + 1;
-				GLOBAL (ip_location) =
-						pSolarSysState->SunDesc[0].location;
+				GLOBAL (ip_location) = pSolarSysState->SunDesc[0].location;
 			}
 		}
 		else
@@ -1656,4 +1659,3 @@ SaveFlagshipState (void)
 	}
 }
 
-
