@@ -138,7 +138,10 @@ forwardToNextEvent (BOOLEAN skipHEE)
 	if (!GameClockRunning ())
 		return;
 
-	SuspendGameClock ();
+	// Must hold GraphicsLock for MoveGameClockDays()
+	// Must acquire GraphicsLock *before* the game clock lock
+	LockMutex (GraphicsLock);
+	LockGameClock ();
 
 	done = !skipHEE;
 	do {
@@ -161,16 +164,12 @@ forwardToNextEvent (BOOLEAN skipHEE)
 					GLOBAL (GameClock.day_index) >= day))))
 				break;
 
-			while (ClockTick () > 0)
-				;
-
-			ResumeGameClock ();
-			SleepThread (ONE_SECOND / 60);
-			SuspendGameClock ();
+			MoveGameClockDays (1);
 		}
 	} while (!done);
 
-	ResumeGameClock ();
+	UnlockGameClock ();
+	UnlockMutex (GraphicsLock);
 }
 
 const char *
@@ -239,15 +238,9 @@ dumpEvent (FILE *out, const EVENT *eventPtr)
 void
 dumpEvents (FILE *out)
 {
-	BOOLEAN restartClock = FALSE;
-
-	if (GameClockRunning ()) {
-		SuspendGameClock ();
-		restartClock = TRUE;
-	}
+	LockGameClock ();
 	ForAllEvents (dumpEventCallback, out);
-	if (restartClock)
-		ResumeGameClock ();
+	UnlockGameClock ();
 }
 
 ////////////////////////////////////////////////////////////////////////////
@@ -541,8 +534,7 @@ activateAllShips (void)
 		if (FleetPtr->icons != NULL)
 				// Skip the Ur-Quan probe.
 		{
-			FleetPtr->ship_flags &= ~(GOOD_GUY | BAD_GUY);
-			FleetPtr->ship_flags |= GOOD_GUY;
+			FleetPtr->allied_state = GOOD_GUY;
 		}
 
 		UnlockFleetInfo (&GLOBAL (avail_race_q), hStarShip);
@@ -593,7 +585,6 @@ forAllMoons (STAR_DESC *star, SOLARSYS_STATE *system, PLANET_DESC *planet,
 void
 UniverseRecurse (UniverseRecurseArg *universeRecurseArg)
 {
-	BOOLEAN clockRunning;
 	ACTIVITY savedActivity;
 	
 	if (universeRecurseArg->systemFuncPre == NULL
@@ -603,9 +594,7 @@ UniverseRecurse (UniverseRecurseArg *universeRecurseArg)
 			&& universeRecurseArg->moonFunc == NULL)
 		return;
 	
-	clockRunning = GameClockRunning ();
-	if (clockRunning)
-		SuspendGameClock ();
+	LockGameClock ();
 	//TFB_DEBUG_HALT = 1;
 	savedActivity = GLOBAL (CurrentActivity);
 	disableInteractivity = TRUE;
@@ -614,8 +603,7 @@ UniverseRecurse (UniverseRecurseArg *universeRecurseArg)
 	
 	disableInteractivity = FALSE;
 	GLOBAL (CurrentActivity) = savedActivity;
-	if (clockRunning)
-		ResumeGameClock ();
+	UnlockGameClock ();
 }
 
 static void
@@ -1469,9 +1457,9 @@ depositQualityString (BYTE quality)
 
 ////////////////////////////////////////////////////////////////////////////
 
-// Which should be GOOD_GUY or BAD_GUY
+// playerNr should be 0 or 1
 STARSHIP*
-findPlayerShip(ELEMENT_FLAGS which) {
+findPlayerShip (SIZE playerNr) {
 	HELEMENT hElement, hNextElement;
 
 	for (hElement = GetHeadElement (); hElement; hElement = hNextElement)
@@ -1482,7 +1470,7 @@ findPlayerShip(ELEMENT_FLAGS which) {
 		hNextElement = GetSuccElement (ElementPtr);
 					
 		if ((ElementPtr->state_flags & PLAYER_SHIP)	&&
-				(ElementPtr->state_flags & (GOOD_GUY | BAD_GUY)) == which)
+				ElementPtr->playerNr == playerNr)
 		{
 			STARSHIP *StarShipPtr;
 			GetElementStarShip (ElementPtr, &StarShipPtr);
@@ -1507,7 +1495,7 @@ resetCrewBattle(void) {
 			(LOBYTE (GLOBAL (CurrentActivity)) == IN_HYPERSPACE))
 		return;
 	
-	StarShipPtr = findPlayerShip (GOOD_GUY);
+	StarShipPtr = findPlayerShip (RPG_PLAYER_NUM);
 	if (StarShipPtr == NULL || StarShipPtr->RaceDescPtr == NULL)
 		return;
 
@@ -1529,7 +1517,7 @@ resetEnergyBattle(void) {
 			(LOBYTE (GLOBAL (CurrentActivity)) == IN_HYPERSPACE))
 		return;
 	
-	StarShipPtr = findPlayerShip (GOOD_GUY);
+	StarShipPtr = findPlayerShip (RPG_PLAYER_NUM);
 	if (StarShipPtr == NULL || StarShipPtr->RaceDescPtr == NULL)
 		return;
 
